{ inputs, config, pkgs, ... }:
{
  imports = [
    (import ./common.nix { inherit inputs config pkgs; })
    (import ../hyprland { inherit inputs pkgs; })
    (import ../ags { inherit inputs config pkgs; })
    ../rofi
    ../alacritty
    ../kitty
    ../firefox
    ../ssh
    ../mpv
  ];

  home.packages = with pkgs; [
    telegram-desktop
    webcord
    devenv
    iwgtk
    element-desktop
    evince
    loupe
    file-roller
    gimp
    obs-studio
    inkscape
    gnome-calendar
    zip
  ];

  services.kdeconnect = {
    enable = true;
    package = pkgs.kdePackages.kdeconnect-kde;
    indicator = true;
  };

  programs.thunderbird = {
    enable = true;
    profiles.default.isDefault = true;
  };

  gtk = {
      enable = true;
      theme = {
          package = pkgs.gnome-themes-extra;
          name = "Adwaita-dark";
      };
      iconTheme = {
          name = "Papirus";
          package = pkgs.papirus-icon-theme;
      };
  };

  home.pointerCursor = {
      gtk.enable = true;
      name = "Adwaita";
      size = 28;
      package = pkgs.adwaita-icon-theme;
  };

  services.cliphist = { enable = true; };

  xdg.mimeApps = {
    enable = true;
    defaultApplications = {
        "application/pdf" = "org.gnome.Evince.desktop";
        "x-scheme-handler/tg" = "org.telegram.desktop.desktop";
        "video/*" = "mpv.desktop";
        "audio/*" = "mpv.desktop";
    };
    associations.added = {
        "x-scheme-handler/tg" = "org.telegram.desktop.desktop";
    };
  };
}
